@@ -3,8 +3,6 @@ test_that("start designs", {
   des2 <- design("Some design")
 
   expect_equal(class(des1), c("edbl_design", "edbl"))
-  expect_equal(des1$name, NULL)
-  expect_equal(des2$name, "Some design")
 
   expect_snapshot({
     des1
